==> openGion6.9.1.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           varchar (  10 )                 NOT NULL            /*  20 帳票ID   */
 , KBTEXT           varchar (   1 )                 NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              varchar (  30 )                 NOT NULL            /*  40 項目     */
 , SEQ              INTEGER             DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        INTEGER             DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       varchar (   9 )     DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            varchar (   1 )                 NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar (  20 )                                     /* 100 設変番号 */
 , FGJ              varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar (  14 )                                     /* 820 登録日時 */
 , PGSET            varchar (  10 )                                     /* 830 作成PG   */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG */
 , USRSET           varchar (  10 )                                     /* 850 作成社員 */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時 */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG   */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG */
 , USRUPD           varchar (  10 )                                     /* 890 更新者   */
);

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           varchar (  10 )                 NOT NULL            /*  20 帳票ID   */
 , KBTEXT           varchar (   1 )                 NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              varchar (  30 )                 NOT NULL            /*  40 項目     */
 , SEQ              INTEGER             DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        INTEGER             DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       varchar (   9 )     DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            varchar (   1 )                 NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    varchar ( 120 )                                     /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         varchar (  20 )                                     /* 100 設変番号 */
 , FGJ              varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            varchar (  14 )                                     /* 820 登録日時 */
 , PGSET            varchar (  10 )                                     /* 830 作成PG   */
 , PGPSET           varchar (  10 )                                     /* 840 作成親PG */
 , USRSET           varchar (  10 )                                     /* 850 作成者   */
 , DYUPD            varchar (  14 )                                     /* 860 更新日時 */
 , PGUPD            varchar (  10 )                                     /* 870 更新PG   */
 , PGPUPD           varchar (  10 )                                     /* 880 更新親PG */
 , USRUPD           varchar (  10 )                                     /* 890 更新者   */
);
